summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xmake-boot-image.sh26
1 files changed, 15 insertions, 11 deletions
diff --git a/make-boot-image.sh b/make-boot-image.sh
index 0961890..a790b17 100755
--- a/make-boot-image.sh
+++ b/make-boot-image.sh
@@ -11,12 +11,12 @@ DEVEL_MODE=y
ROOTCMD=sudo
WGET="wget" #"wget --no-check-certificate"
# You probably need to tweak version numbers if you have an HTTP 404 - Not found error
-KERNEL_TARBALL_URL=https://cdn.kernel.org/pub/linux/kernel/v4.x/linux-4.6.tar.xz
+KERNEL_TARBALL_URL=https://cdn.kernel.org/pub/linux/kernel/v4.x/linux-4.17.3.tar.xz
KCONFIGLIB_MAIN_URL=https://raw.githubusercontent.com/ulfalizer/Kconfiglib/v7.0.0/kconfiglib.py
KCONFIGLIB_PATCH_URL=https://raw.githubusercontent.com/ulfalizer/Kconfiglib/master/makefile.patch
-NIC_FIRMWARE_URL=http://fr.archive.ubuntu.com/ubuntu/pool/main/l/linux-firmware/nic-firmware_1.162_all.udeb
-UFTP_TARBALL_URL=http://downloads.sourceforge.net/project/uftp-multicast/source-tar/uftp-4.9.3.tar.gz
-BUSYBOX_BIN_URL=https://busybox.net/downloads/binaries/busybox-x86_64
+NIC_FIRMWARE_URL=http://fr.archive.ubuntu.com/ubuntu/pool/main/l/linux-firmware/nic-firmware_1.174.20_all.udeb
+UFTP_TARBALL_URL=http://downloads.sourceforge.net/project/uftp-multicast/source-tar/uftp-4.9.7.tar.gz
+BUSYBOX_BIN_URL=https://busybox.net/downloads/binaries/1.28.1-defconfig-multiarch/busybox-x86_64
PCI_IDS_URL=https://pci-ids.ucw.cz/v2.2/pci.ids
USB_IDS_URL=https://usb-ids.gowdy.us/usb.ids
@@ -54,12 +54,15 @@ function mkchroot
# Environement and dependencies #
#################################
codename=$(lsb_release -sc || true)
-if [ "x$codename" != "xjessie" ]
+if [ "x$codename" != "xbuster" ]
then cat >&2 <<EOT
-This script is tested only on Debian 8 (aka jessie).
+This script is tested only on GNU/Linux Debian 10 amd64 (aka Buster).
The fastest way to have the right environment is :
* download debian live http://cdimage.debian.org/debian-cd/current-live/amd64/iso-hybrid/debian-live-8.5.0-amd64-standard.iso
* burn it or copy it on a USB stick (as raw, with "cp XX.iso /dev/sdX"), alternatively launch a VM with it
* run this script from there
EOT
exit 1
@@ -76,15 +79,16 @@ if [ ! -e "$WORKDIR/apt-install-done" ]
then # Dependencies of this script (assuming default debian install or live)
$ROOTCMD apt-get install wget libncurses5-dev coreutils syslinux
# Dependencies for kernel building
- $ROOTCMD apt-get build-dep linux-source
+ $ROOTCMD apt-get install build-essential flex bison
# Dependancies for kernel tools
[ "x$DEVEL_MODE" == "xy" ] && $ROOTCMD apt-get install libelf-dev libunwind-dev \
- libdw-dev libaudit-dev libssl-dev libslang2-dev libiberty-dev
+ libdw-dev libaudit-dev libssl-dev libslang2-dev libnuma-dev \
+ systemtap-sdt-dev python-dev binutils-dev libiberty-dev libbabeltrace-ctf-dev
# Optionnally qemu to run the result for santity checking
[ "x$DEVEL_MODE" = "xy" ] && $ROOTCMD apt-get install qemu-system-x86
# Dependencies to put into the initrd
$ROOTCMD apt-get install dmidecode pciutils usbutils lshw sysstat iftop strace
- $ROOTCMD apt-get install partclone sfdisk udpcast gdisk efibootmgr tcpdump
+ $ROOTCMD apt-get install partclone fdisk udpcast gdisk efibootmgr tcpdump
> "$WORKDIR/apt-install-done"
fi
@@ -54,12 +54,15 @@ function mkchroot
The fastest way to have the right environment is :
- * download debian live http://cdimage.debian.org/debian-cd/current-live/amd64/iso-hybrid/debian-live-8.5.0-amd64-standard.iso
- * burn it or copy it on a USB stick (as raw, with "cp XX.iso /dev/sdX"), alternatively launch a VM with it
+ * download Debian 10 amd64 live
+ * here : http://cdimage.debian.org/debian-cd/current-live/amd64/iso-hybrid/
+ * or here : http://cdimage.debian.org/mirror/cdimage/archive/
+ * burn it or copy it on a USB stick (as raw, with "sudo cp XX.iso /dev/sdX")
+ * alternatively launch a VM with it
* run this script from there
EOT